==> jc-1.4.0.tar.gz: soot/jimple/toolkits/annotation/arraycheck/ArrayReferenceNode.h <==
// class soot.jimple.toolkits.annotation.arraycheck.ArrayReferenceNode

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 179d83933b461e23 soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode_H_
#define _JC_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Local$object;
struct _jc_soot_SootMethod$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$sub_refs	_jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$sub_refs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$sub_nonrefs	_jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$refs	_jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$refs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$nonrefs	_jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$object	_jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$object;

typedef const struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$vmethods	_jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$vmethods;
typedef const struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$vtable	_jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$vtable;
typedef const struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$vtype	_jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$method$_init$197e354f306c7f2c(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$object *, struct _jc_soot_SootMethod$object *, struct _jc_object *);

// Virtual methods
extern jboolean _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$method$equals$8a15e0625571c581(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_object *_jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$method$getLocal$a441b41cec934e4e(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$object *);
extern struct _jc_soot_SootMethod$object *_jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$method$getMethod$04d7c221deab35ce(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$object *);
extern jint _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$method$hashCode$53152098849316df(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$object *);
extern struct _jc_java_lang_String$object *_jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$method_info$getLocal$a441b41cec934e4e;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$method_info$getMethod$04d7c221deab35ce;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$method_info$hashCode$53152098849316df;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$object *, struct _jc_java_lang_Object$object *);
	struct _jc_object	*(*getLocal$a441b41cec934e4e)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$object *);
	struct _jc_soot_SootMethod$object	*(*getMethod$04d7c221deab35ce)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$object *);
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$object *);
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$object *);
};

// Vtable
struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$vmethods	soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode;
};

// Vtype
struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$sub_refs {
	struct _jc_soot_SootMethod$object	*m;
	struct _jc_object	*l;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$refs {
    _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$sub_refs	soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$sub_nonrefs	soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$object {
	_jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$vtype	*vtype;
	_jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$vtype _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$class_object;

#endif	/* _JC_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode_H_ */

==> jc-1.4.6.tar.gz: soot/jimple/toolkits/annotation/arraycheck/ArrayReferenceNode.h <==
// class soot.jimple.toolkits.annotation.arraycheck.ArrayReferenceNode

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 179d83933b461e23 soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode_H_
#define _JC_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Local$object;
struct _jc_soot_SootMethod$object;

// Typedefs
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$sub_refs	_jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$sub_refs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$sub_nonrefs	_jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$sub_nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$refs	_jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$refs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$nonrefs	_jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$nonrefs;
typedef struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$object	_jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$object;

typedef const struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$vmethods	_jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$vmethods;
typedef const struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$vtable	_jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$vtable;
typedef const struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$vtype	_jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$vtype;

// Constructors
extern void _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$method$_init$197e354f306c7f2c(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$object *, struct _jc_soot_SootMethod$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern jboolean _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$method$equals$8a15e0625571c581(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_object *_jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$method$getLocal$a441b41cec934e4e(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$object *) _JC_JCNI_ATTR;
extern struct _jc_soot_SootMethod$object *_jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$method$getMethod$04d7c221deab35ce(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$object *) _JC_JCNI_ATTR;
extern jint _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$method$hashCode$53152098849316df(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$method$toString$7ea43b33b80a3070(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$method_info$equals$8a15e0625571c581;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$method_info$getLocal$a441b41cec934e4e;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$method_info$getMethod$04d7c221deab35ce;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$method_info$hashCode$53152098849316df;
extern _jc_method _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$method_info$toString$7ea43b33b80a3070;

// Virtual methods structure
struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$vmethods {
	jboolean	(*equals$8a15e0625571c581)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_object	*(*getLocal$a441b41cec934e4e)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$object *) _JC_JCNI_ATTR;
	struct _jc_soot_SootMethod$object	*(*getMethod$04d7c221deab35ce)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$object *) _JC_JCNI_ATTR;
	jint	(*hashCode$53152098849316df)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*toString$7ea43b33b80a3070)(_jc_env *, struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$vmethods	soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode;
};

// Vtype
struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$vtype {
	_jc_type			type;
	_jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$sub_refs {
	struct _jc_soot_SootMethod$object	*m;
	struct _jc_object	*l;
};

// Reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$refs {
    _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$sub_refs	soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$sub_nonrefs	soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode;
};

// Object instance structure
struct _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$object {
	_jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$vtype	*vtype;
	_jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$vtype _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode$class_object;

#endif	/* _JC_soot_jimple_toolkits_annotation_arraycheck_ArrayReferenceNode_H_ */
